/**********************************************************************
* mouse.h
* 
* The mouse interface through INT 33.
* NOTE: The pointer is not visible in the 2nd page of a Hercules card
**********************************************************************
                    This file is part of

         STK -- The sprite toolkit -- version 1.0

              Copyright (C) Jari Karjala 1990

The sprite toolkit (STK) is a FreeWare toolkit for creating high
resolution sprite graphics with PCompatible hardware. This toolkit 
is provided as is without any warranty or such thing. See the file
COPYING for further information.

**********************************************************************
**********************************************************************/

#if     !defined(__MOUSE_H_)
#define __MOUSE_H_

/** Codes for button presses **/
#define BUTTON_LEFT         1
#define BUTTON_RIGHT        2
#define BUTTON_MS_MIDDLE    (BUTTON_RIGHT | BUTTON_LEFT)
#define BUTTON_MIDDLE       4

/* First mask and then shape bitmap (must be WORDs) */
typedef unsigned int MOUSE_POINTER[2][16];

#ifndef NO_EXTERNS
extern MOUSE_POINTER mouse_pointer_arrow;    /* HotSpot 1,1   */
extern MOUSE_POINTER mouse_pointer_hourglass;/* HotSpot 7,7  */
extern MOUSE_POINTER mouse_pointer_cross;    /* HotSpot 7,7   */
#else
#undef NO_EXTERNS
#endif

/** For further information, see the mouse documention **/
int     mouse_driver_init(void);                                /**  0 **/
void    mouse_show_pointer(void);                               /**  1 **/
void    mouse_hide_pointer(void);                               /**  2 **/
void    mouse_get_pointer_xy(int *x, int *y);                   /**  3 **/
void    mouse_get_rel_pointer_xy(int *x, int *y);               /** 11 **/
int     mouse_get_buttons(void);                                /**  3 **/
int     mouse_get_presses(int buttons);                         /**  5 **/
int     mouse_get_releases(int buttons);                        /**  6 **/
void    mouse_set_pointer_xy(int x, int y);                     /**  4 **/
void    mouse_set_sensitivity(int x, int y);                    /** 15 **/
void    mouse_set_pointer_shape(int HotX, int HotY, MOUSE_POINTER shape);
void    mouse_set_pointer_window(int a, int b, int c, int d);    /**  7 **/
void    mouse_disable_pointer_window(int a, int b, int c, int d);/** 16 **/
void    mouse_set_light_pen(int a);                         /** 13 & 14 **/

/**********************************************************************
* Initialize the mouse driver, set the pointer shape and pointer window.
* Return: the number of buttons or 0 if no mouse driver detected
**********************************************************************/
int     mouse_initialize(void);

#endif
