/**********************************************************************
* spr_low.h
*
* The hardware dependent parts of the sprite support. 
**********************************************************************
                    This file is part of

          STK -- The sprite toolkit -- version 1.0

              Copyright (C) Jari Karjala 1990

The sprite toolkit (STK) is a FreeWare toolkit for creating high
resolution sprite graphics with PCompatible hardware. This toolkit 
is provided as is without any warranty or such thing. See the file
COPYING for further information.

**********************************************************************
**********************************************************************/

/**********************************************************************
* ADDR
* Return the address of the given (x,y) coordinate pair in the
* given graphics page.
* 
* x,y     X,Y coordinates
* page    The graphics page (0/1)
*
* Return: far pointer into the screen.
**********************************************************************/

/**********************************************************************
* PUT
* Put the given shape into the given address using the given mask and
* saving the old contents into the given buffer. The shape and mask
* data must be combined as described in the file sprP.h and they
* must reside in the same segment as save buffer.
* 
* shape   The address of the combined shape/mask data
* dest    The destination address in the frame buffer
* save    The address of the save buffer
* w       The width of the shape in bytes
* h       The height of the shape in pixels
**********************************************************************/

/**********************************************************************
* ERASE
* Erase the sprite from screen by putting the saved data back
* 
* dest    The destination address in the frame buffer
* save    The address of the save buffer
* w       The width of the shape in bytes
* h       The height of the shape in pixels
**********************************************************************/


/*** Hercules graphics card **/
BYTE far *spr_low_herc_addr(WORD x, WORD y, BYTE page);
void spr_low_herc_put(BYTE far *shape, BYTE far *dest, BYTE far *save, 
                      WORD w, WORD h);
void spr_low_herc_erase(BYTE far *dest, BYTE far *save, WORD w, WORD h);

/*** EGA/VGA graphics card in B/W 640x350 mode **/
BYTE far *spr_low_ega_mono_addr(WORD x, WORD y, BYTE page);
void spr_low_ega_mono_put(BYTE far *shape, BYTE far *dest, BYTE far *save, 
                      WORD w, WORD h);
void spr_low_ega_mono_erase(BYTE far *dest, BYTE far *save, WORD w, WORD h);

